@@ -85,7 +85,7 @@ pfb_output_binary(unsigned char *s, int len)
 }
 
 static void
-pfb_output_end()
+pfb_output_end(void)
 {
   pfb_writer_end(&w);
 }
@@ -132,7 +132,7 @@ error(const char *message, ...)
 }
 
 
-void
+static void
 short_usage(void)
 {
   fprintf(stderr, "Usage: %s [OPTION]... [INPUT [OUTPUT]]\n\
@@ -141,7 +141,7 @@ Try `%s --help' for more information.\n",
 }
 
 
-void
+static void
 usage(void)
 {
   printf("\
@@ -210,7 +210,7 @@ main(int argc, char *argv[])
 
      case VERSION_OPT:
       printf("t1binary (LCDF t1utils) %s\n", VERSION);
-      printf("Copyright (C) 1992-2003 I. Lee Hetherington, Eddie Kohler et al.\n\
+      printf("Copyright (C) 1992-2010 I. Lee Hetherington, Eddie Kohler et al.\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
